/* reac.h   reaction structure*/

extern struct reac { /*Reaction Parameters also used in fortran common block*/
    float edisp;
    float e1;
    float mass[/*5*/13];
    float q1;
} reac;

int reac_init(void);          /*reaction definition*/

float reac_edisp(void);
void reacs_edisp(float);

float reac_e1(void);
void reacs_e1(float);

float reac_mass(int);
void reacs_mass(int, float);


